GlintAacConfig class final

Mirror of struct glint_aac_config (zero-init the reserved tail).

Inheritance
Implemented types
Available extensions

Constructors

GlintAacConfig()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bitrate int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
numChannels int
getter/setter pair
quality int
getter/setter pair
reserved Array<Int32>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
getter/setter pair
vbr int
getter/setter pair
vbrQuality int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited