GlintDecodedAudioI16 class

Decode a whole encoded stream (MP3 / AAC-LC / Ogg-Opus, format auto- detected from the header) to interleaved float PCM. Throws StateError on unrecognized or corrupt input. Decoded int16 audio.

Constructors

GlintDecodedAudioI16(Int16List pcm, int sampleRate, int channels)

Properties

channels int
final
hashCode int
The hash code for this object.
no setterinherited
pcm Int16List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited