GlintMp3Decoder class
MPEG-1/2 Layer III decoder.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
Uint8List data) → Float32List -
Decode a whole stream (walks frames, skips ID3v2). Returns
interleaved float PCM.
inherited
-
dispose(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited