GlintAacEncoder class
AAC-LC encoder (ADTS output). Same interleaved-PCM conventions as GlintEncoder; one encode call consumes samplesPerFrame (1024) samples per channel and returns one ADTS frame. flush returns the two tail frames and must be called at end of stream (encoder delay: 2048 samples; the first frame is a silence priming frame).
Constructors
Properties
- channels → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samplesPerFrame ↔ int
-
latefinal
Methods
-
dispose(
) → void - Destroy the encoder and free native resources.
-
encode(
Int16List pcm) → Uint8List - Encode one frame of interleaved 16-bit PCM samples.
-
flush(
) → Uint8List - Flush the encoder, returning the two tail ADTS frames.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited