GlintDecodedAudio class
Decoded audio: interleaved float PCM plus its stream parameters.
Constructors
- GlintDecodedAudio(Float32List pcm, int sampleRate, int channels)
Properties
- channels → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pcm → Float32List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited